# Better Automation v3
[![Telegram channel](https://img.shields.io/endpoint?url=https://runkit.io/damiankrawczyk/telegram-badge/branches/master?url=https://t.me/cum_insider)](https://t.me/cum_insider)
[![PyPI version info](https://img.shields.io/pypi/v/better-automation.svg)](https://pypi.python.org/pypi/better-automation)
[![PyPI supported Python versions](https://img.shields.io/pypi/pyversions/better-automation.svg)](https://pypi.python.org/pypi/better-automation)
[![PyPI downloads per month](https://img.shields.io/pypi/dm/better-automation.svg)](https://pypi.python.org/pypi/better-automation)

Набор инструментов для автоматизации:
- Все из библиотеки [tweepy-self](https://github.com/alenkimov/tweepy-self): логин, анлок, totp, OAuth, OAuth2, твиты, лайки, сообщения и многое другое..
- googleapis для OAuth2. Использовалось в Well3 (yogapetz) для авторизации и может использоваться в других проектах.
- Google login и OAuth2 на [Playwright](https://github.com/microsoft/playwright).

Особенности:
- Поддержка прокси в любом из существующих форматов благодаря [better-proxy](https://github.com/alenkimov/better_proxy)
- Все (кроме Google) на запросах через [curl_cffi](https://github.com/yifeikong/curl_cffi)

More libraries of the family:
- [tweepy-self](https://github.com/alenkimov/tweepy-self)
- [better-web3](https://github.com/alenkimov/better_web3)
- [better-proxy](https://github.com/alenkimov/better_proxy)

## Installation
```bash
pip install better-automation
```
